import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useMemo, useState } from "react";
import { View, Text, TouchableOpacity, Image } from "react-native";
import { Label } from "./Label";
import colors from "../colors";
import { SELECT_HEIGHT } from "../sizes";
import BottomSelectModal from "./BottomSelectModal";
/**
 * Button Component
 * @props label {string} Select Input 상단 타이틀
 * @props style {object} 컨테이너 스타일
 * @props inputStyle {boolean} Select Input 스타일
 * @props value {string | number} Current value
 * @props placeholder {string}
 * @props disabled {boolean}
 * @props options {string[]} select 리스트
 * @props onPress {(value: string) => void} 클릭 이벤트
 * @props required {boolean} 필수일 경우 라벨 옆 *추가
 * @props textStyle {object} 텍스트 스타일
 * @props error {string | undefined} 에러메세지(하단에 에러 메세지 표시)
 */
const SelectInput = ({ label, style, value, placeholder = "선택", disabled = false, onPress, options, required, inputStyle, textStyle, error, }) => {
    const [isModalVisible, setIsModalVisible] = useState(false);
    const renderValue = useMemo(() => options.find((o) => o === value), [options.length, value]);
    const handleSelect = (value) => {
        setIsModalVisible(false);
        onPress(value);
    };
    return (_jsxs(View, { style: style, children: [label ? _jsx(Label, { label: label, required: required }) : null, _jsx(View, { style: {
                    flexDirection: "row",
                    justifyContent: "space-between",
                }, children: _jsxs(TouchableOpacity, { disabled: disabled, activeOpacity: 1, style: [
                        {
                            flexDirection: "row",
                            flex: 1,
                            justifyContent: "space-between",
                            alignItems: "center",
                            height: SELECT_HEIGHT,
                            backgroundColor: disabled ? colors.GRAY : colors.WHITE,
                            borderRadius: 3,
                            borderColor: colors.GRAY_RIGHT,
                            borderWidth: 1,
                            paddingHorizontal: 10,
                        },
                        inputStyle,
                    ], onPress: () => setIsModalVisible(true), children: [renderValue ? (_jsx(Text, { style: [
                                {
                                    fontSize: 15,
                                    marginLeft: 5,
                                    color: colors.BLACK,
                                },
                                textStyle,
                            ], children: renderValue })) : (_jsx(Text, { style: [
                                {
                                    fontSize: 15,
                                    marginLeft: 5,
                                },
                                { color: colors.GRAY },
                                textStyle,
                            ], children: placeholder })), _jsx(Image, { source: require("../assets/chevron-down.png"), style: { width: 15, height: 15 } })] }) }), error && (_jsx(Text, { numberOfLines: 1, ellipsizeMode: "tail", style: { marginTop: 5, color: "red" }, children: error })), _jsx(BottomSelectModal, { value: value, isVisible: isModalVisible, onPress: handleSelect, close: () => setIsModalVisible(false), selectableList: options })] }));
};
export default SelectInput;
